@@ -36,15 +36,13 @@ func (c *command) statementExceptionList(cmd *cobra.Command, args []string) erro
 		return err
 	}
 
-	orgId := c.Context.GetCurrentOrganization()
-
-	exceptions, err := client.GetExceptions(environmentId, args[0], orgId)
+	exceptions, err := client.GetExceptions(environmentId, args[0], c.Context.GetCurrentOrganization())
 	if err != nil {
 		return err
 	}
 
 	list := output.NewList(cmd)
-	for _, exception := range exceptions.Data {
+	for _, exception := range exceptions {
 		list.Add(&exceptionOut{
 			Name:       exception.GetName(),
 			Timestamp:  exception.GetTimestamp(),
