@@ -11,11 +11,13 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/spf13/cobra"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
 	ccloudv1 "github.com/confluentinc/ccloud-sdk-go-v1-public"
 
+	"github.com/confluentinc/cli/v3/pkg/errors"
 	"github.com/confluentinc/cli/v3/pkg/utils"
 	pversion "github.com/confluentinc/cli/v3/pkg/version"
 	testserver "github.com/confluentinc/cli/v3/test/test-server"
@@ -37,7 +39,7 @@ var (
 	apiCredentialName = fmt.Sprintf("api-key-%s", apiKeyString)
 	kafkaClusterID    = "anonymous-id"
 	contextName       = "my-context"
-	environmentId     = "acc-123"
+	environmentId     = "env-123456"
 	cloudPlatforms    = []string{
 		"devel.cpdev.cloud",
 		"stag.cpdev.cloud",
@@ -133,10 +135,10 @@ func SetupTestInputs(isCloud bool) *TestInputs {
 		PlatformName:       platform.Name,
 		Credential:         loginCredential,
 		CredentialName:     loginCredential.Name,
-		CurrentEnvironment: "acc-123",
+		CurrentEnvironment: "env-123456",
 		Environments: map[string]*EnvironmentContext{
-			"acc-123":  {},
-			"env-flag": {},
+			"env-123456": {},
+			"env-flag":   {},
 		},
 		State: regularOrgContextState,
 	}
@@ -440,7 +442,7 @@ func TestConfig_OverwrittenKafka(t *testing.T) {
 		ctx := test.config.Context()
 		test.config.SetOverwrittenCurrentKafkaCluster(test.overwrittenVal)
 		// resolve should reset the active kafka to be the overwritten value and return the flag value to be used in restore
-		tempKafka := test.config.resolveOverwrittenKafka()
+		tempKafka := test.config.resolveOverwrittenKafkaCluster()
 		require.Equal(t, test.activeKafka, tempKafka)
 		if ctx.KafkaClusterContext.EnvContext && ctx.KafkaClusterContext.GetCurrentKafkaEnvContext() != nil {
 			require.Equal(t, test.overwrittenVal, ctx.KafkaClusterContext.GetCurrentKafkaEnvContext().ActiveKafkaCluster)
@@ -448,7 +450,7 @@ func TestConfig_OverwrittenKafka(t *testing.T) {
 			require.Equal(t, test.overwrittenVal, ctx.KafkaClusterContext.ActiveKafkaCluster)
 		}
 		// restore should reset the active kafka to be the flag value
-		test.config.restoreOverwrittenKafka(tempKafka)
+		test.config.restoreOverwrittenKafkaCluster(tempKafka)
 		if ctx.KafkaClusterContext.EnvContext && ctx.KafkaClusterContext.GetCurrentKafkaEnvContext() != nil {
 			require.Equal(t, tempKafka, ctx.KafkaClusterContext.GetCurrentKafkaEnvContext().ActiveKafkaCluster)
 		} else {
@@ -1070,3 +1072,57 @@ func TestConfig_IsOnPrem_False(t *testing.T) {
 		require.False(t, cfg.IsOnPremLogin())
 	}
 }
+
+func TestParseFlagsIntoConfig(t *testing.T) {
+	configBase := AuthenticatedCloudConfigMock()
+
+	configFlag := AuthenticatedCloudConfigMock()
+	configFlag.Contexts["test-context"] = &Context{Name: "test-context"}
+
+	tests := []struct {
+		name           string
+		context        string
+		config         *Config
+		errMsg         string
+		suggestionsMsg string
+	}{
+		{
+			name:   "read context from config",
+			config: configBase,
+		},
+		{
+			name:    "read context from flag",
+			context: "test-context",
+			config:  configFlag,
+		},
+		{
+			name:    "bad-context specified with flag",
+			context: "bad-context",
+			config:  configFlag,
+			errMsg:  fmt.Sprintf(errors.ContextDoesNotExistErrorMsg, "bad-context"),
+		},
+	}
+	for _, test := range tests {
+		cmd := &cobra.Command{Run: func(cmd *cobra.Command, args []string) {}}
+		cmd.Flags().String("context", "", "Context name.")
+		err := cmd.ParseFlags([]string{"--context", test.context})
+		require.NoError(t, err)
+		initialCurrentContext := test.config.CurrentContext
+		err = test.config.ParseFlagsIntoConfig(cmd)
+		if test.errMsg != "" {
+			require.Error(t, err)
+			require.Equal(t, test.errMsg, err.Error())
+			if test.suggestionsMsg != "" {
+				errors.VerifyErrorAndSuggestions(require.New(t), err, test.errMsg, test.suggestionsMsg)
+			}
+		} else {
+			require.NoError(t, err)
+			ctx := test.config.Context()
+			if test.context != "" {
+				require.Equal(t, test.context, ctx.Name)
+			} else {
+				require.Equal(t, initialCurrentContext, ctx.Name)
+			}
+		}
+	}
+}
