@@ -45,6 +45,10 @@ var ccloudV2Routes = []route{
 	{"/iam/v2/identity-providers/{id}", handleIamIdentityProvider},
 	{"/iam/v2/identity-providers/{provider_id}/identity-pools", handleIamIdentityPools},
 	{"/iam/v2/identity-providers/{provider_id}/identity-pools/{id}", handleIamIdentityPool},
+	{"/iam/v2/ip-filters", handleIamIpFilters},
+	{"/iam/v2/ip-filters/{id}", handleIamIpFilter},
+	{"/iam/v2/ip-groups", handleIamIpGroups},
+	{"/iam/v2/ip-groups/{id}", handleIamIpGroup},
 	{"/iam/v2/invitations", handleIamInvitations},
 	{"/iam/v2/role-bindings", handleIamRoleBindings},
 	{"/iam/v2/role-bindings/{id}", handleIamRoleBinding},
