@@ -1753,8 +1753,8 @@ func handleKafkaClustersClusterIdBrokersTasksTaskTypeGet(t *testing.T) http.Hand
 					TaskType:        cpkafkarestv3.BrokerTaskType(vars["task_type"]),
 					TaskStatus:      "SUCCESS",
 					SubTaskStatuses: map[string]string{"partition_reassignment_status": "IN_PROGRESS"},
-					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
-					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
+					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
+					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
 				},
 				{
 					ClusterId:       vars["cluster_id"],
@@ -1762,8 +1762,8 @@ func handleKafkaClustersClusterIdBrokersTasksTaskTypeGet(t *testing.T) http.Hand
 					TaskType:        cpkafkarestv3.BrokerTaskType(vars["task_type"]),
 					TaskStatus:      "SUCCESS",
 					SubTaskStatuses: map[string]string{"broker_shutdown_status": "COMPLETED"},
-					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
-					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
+					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
+					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
 					ErrorCode:       &errorCode,
 					ErrorMessage:    &errorMessage,
 				},
@@ -1787,8 +1787,8 @@ func handleKafkaClustersClusterIdBrokersTasksGet(t *testing.T) http.HandlerFunc
 					TaskType:        cpkafkarestv3.BROKERTASKTYPE_REMOVE_BROKER,
 					TaskStatus:      "SUCCESS",
 					SubTaskStatuses: map[string]string{"partition_reassignment_status": "IN_PROGRESS"},
-					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
-					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
+					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
+					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
 				},
 				{
 					ClusterId:       vars["cluster_id"],
@@ -1796,8 +1796,8 @@ func handleKafkaClustersClusterIdBrokersTasksGet(t *testing.T) http.HandlerFunc
 					TaskType:        cpkafkarestv3.BROKERTASKTYPE_ADD_BROKER,
 					TaskStatus:      "SUCCESS",
 					SubTaskStatuses: map[string]string{"partition_reassignment_status": "IN_PROGRESS"},
-					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
-					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
+					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
+					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
 					ErrorCode:       &errorCode,
 					ErrorMessage:    &errorMessage,
 				},
@@ -1819,8 +1819,8 @@ func handleKafkaClustersClusterIdBrokersBrokerIdTasksTaskTypeGet(t *testing.T) h
 			TaskType:        cpkafkarestv3.BrokerTaskType(vars["task_type"]),
 			TaskStatus:      "SUCCESS",
 			SubTaskStatuses: map[string]string{"partition_reassignment_status": "IN_PROGRESS"},
-			CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
-			UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
+			CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
+			UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
 			ErrorMessage:    &errorMessage,
 			ErrorCode:       &errorCode,
 		})
@@ -1842,8 +1842,8 @@ func handleKafkaClustersClusterIdBrokersBrokerIdTasksGet(t *testing.T) http.Hand
 					TaskType:        cpkafkarestv3.BROKERTASKTYPE_REMOVE_BROKER,
 					TaskStatus:      "SUCCESS",
 					SubTaskStatuses: map[string]string{"partition_reassignment_status": "IN_PROGRESS"},
-					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
-					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
+					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
+					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
 				},
 				{
 					ClusterId:       vars["cluster_id"],
@@ -1851,8 +1851,8 @@ func handleKafkaClustersClusterIdBrokersBrokerIdTasksGet(t *testing.T) http.Hand
 					TaskType:        cpkafkarestv3.BROKERTASKTYPE_ADD_BROKER,
 					TaskStatus:      "SUCCESS",
 					SubTaskStatuses: map[string]string{"partition_reassignment_status": "IN_PROGRESS"},
-					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
-					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.FixedZone("UTC-8", -8*60*60)),
+					CreatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
+					UpdatedAt:       time.Date(2021, 7, 1, 0, 0, 0, 0, time.UTC),
 					ErrorCode:       &errorCode,
 					ErrorMessage:    &errorMessage,
 				},
